{-----------------------------------------------------------------------------
JEDI File Re-Opener

   Source file IniContainer.pas

The contents of this file are subject to the Mozilla Public License
Version 1.1 (the "License"); you may not use this file except in compliance
with the License. You may obtain a copy of the License at
http://www.mozilla.org/NPL/NPL-1_1Final.html

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either expressed or implied. See the License for
the specific language governing rights and limitations under the License.

Original Developer: Michael Beck <mbeck@bigfoot.com>
http://www.geocities.com/beckmi/delphi.htm

Contributors: Robert Cerny [robert.cerny@neosys.xrs.si]
              Francis Parlant [fparlant@ordimega.com]

Last Modified: 2001-02-23
Current Version: 1.54

You may retrieve the latest version of this file at the Project JEDI home page,
located at http://www.delphi-jedi.org

Known Issues:
-----------------------------------------------------------------------------}
unit IniContainer;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs, inifiles
  , jvReopenerInterfaces, jvReopenerClasses, Menus
  ;

type

  TIniContainer = class(TInterfacedObject, IOptionsMemento, IReopenerFiles {, IListViewMemento})
  private
    { Private declarations }
    FIniFile: TMemIniFile;
    FIgnoreDefaultUnits: Boolean;

    FFormPersistance: Boolean;
    FSortPersistance: Boolean;
    FColumnPersistance: Boolean;
    FLocalDate: Boolean;

    FDefaultPage: Integer;
    FlstPAS: TMyStringList;
    FlstBPG: TMyStringList;
    FlstDPR: TMyStringList;
    FlstDPK: TMyStringList;
    FlstOTH: TMyStringList;
    FCapacityPAS: Integer;
    FCapacityBPG: Integer;
    FCapacityDPR: Integer;
    FCapacityDPK: Integer;
    FCapacityOTH: Integer;
    FCapacityFAV: Integer;
    FlstFAV: TMyStringList;
    fShortcut: TShortcut;
    FFormSize: string;
    FMenuItem: TMenuItem;

    {    FColumnSizesBPG: string;
        FColumnSortingBPG: string;
        FColumnSizesDPR: string;
        FColumnSortingDPR: string;
        FColumnSizesPAS: string;
        FColumnSortingPAS: string;
        FColumnSizesDPK: string;
        FColumnSortingDPK: string;
        FColumnSizesFAV: string;
        FColumnSortingFAV: string;
        FColumnSizesOTH: string;
        FColumnSortingOTH: string;}

    procedure ReadAll;
    procedure ReadIniFile(const List: TMyStringList; MySection: string);

    procedure WriteIniFile(const List: TMyStringList; Section: string);
    procedure CheckForIni;

    //IReopenerFiles
    function GetlstBPG: TMyStringList;
    function GetlstDPK: TMyStringList;
    function GetlstDPR: TMyStringList;
    function GetlstOTH: TMyStringList;
    function GetlstPAS: TMyStringList;
    function GetlstFAV: TMyStringList;

    procedure SetlstBPG(const Value: TMyStringList);
    procedure SetlstDPK(const Value: TMyStringList);
    procedure SetlstDPR(const Value: TMyStringList);
    procedure SetlstOTH(const Value: TMyStringList);
    procedure SetlstPAS(const Value: TMyStringList);
    procedure SetlstFAV(const Value: TMyStringList);

    //IOptionsMemento

    procedure SetDefaultPage(const Value: Integer);
    procedure SetIgnoreDefaultUnits(const Value: Boolean);
    procedure SetCapacityBPG(const Value: Integer);
    procedure SetCapacityDPK(const Value: Integer);
    procedure SetCapacityDPR(const Value: Integer);
    procedure SetCapacityOTH(const Value: Integer);
    procedure SetCapacityPAS(const Value: Integer);
    procedure SetCapacityFAV(const Value: Integer);

    function GetCapacityBPG: Integer;
    function GetCapacityDPK: Integer;
    function GetCapacityDPR: Integer;
    function GetCapacityOTH: Integer;
    function GetCapacityPAS: Integer;
    function GetCapacityFAV: Integer;

    function GetDefaultPage: Integer;
    function GetIgnoreDefaultUnits: Boolean;
    function GetColumnPersistance: Boolean;
    function GetFormPersistance: Boolean;
    function GetSortPersistance: Boolean;
    function GetLocalDate: Boolean;
    function GetFormSize: string;

    procedure SetColumnPersistance(const Value: Boolean);
    procedure SetFormPersistance(const Value: Boolean);
    procedure SetSortPersistance(const Value: Boolean);

    procedure SetLocalDate(const Value: Boolean);
    procedure SetFormSize(const Value: string);
    function GetShortcut: TShortcut;
    procedure SetShortcut(Value: TShortcut);
    procedure SetMenuItem(const Value: TMenuItem);

  protected
    { Protected declarations }
    procedure UpdateIniFile;
    property MyIniFile: TMemIniFile read FIniFile write FIniFile;

    property lstBPG: TMyStringList read GetlstBPG write SetlstBPG;
    property lstDPR: TMyStringList read GetlstDPR write SetlstDPR;
    property lstPAS: TMyStringList read GetlstPAS write SetlstPAS;
    property lstDPK: TMyStringList read GetlstDPK write SetlstDPK;
    property lstOTH: TMyStringList read GetlstOTH write SetlstOTH;
    property lstFAV: TMyStringList read GetlstFAV write SetlstFAV;

  public
    { Public declarations }
    constructor create;
    destructor Destroy; override;
    procedure SaveAll;
    procedure LogOpenedFile(FileName: string);
    procedure LogClosingFile(FileName: string);
    function GetList(S: string): TMyStringList;

    property CapacityBPG: Integer read GetCapacityBPG write SetCapacityBPG;
    property CapacityDPR: Integer read GetCapacityDPR write SetCapacityDPR;
    property CapacityPAS: Integer read GetCapacityPAS write SetCapacityPAS;
    property CapacityDPK: Integer read GetCapacityDPK write SetCapacityDPK;
    property CapacityOTH: Integer read GetCapacityOTH write SetCapacityOTH;
    property CapacityFAV: Integer read GetCapacityFAV write SetCapacityFAV;

    property FormSize: string read FFormSize write SetFormSize;

    property IgnoreDefaultUnits: Boolean read GetIgnoreDefaultUnits write SetIgnoreDefaultUnits;
    property DefaultPage: Integer read GetDefaultPage write SetDefaultPage;

    property FormPersistance: Boolean read GetFormPersistance write SetFormPersistance;
    property SortPersistance: Boolean read GetSortPersistance write SetSortPersistance;
    property ColumnPersistance: Boolean read GetColumnPersistance write SetColumnPersistance;
    property MenuShortcut: TShortcut read GetShortcut write SetShortcut;
    property LocalDate: Boolean read GetLocalDate write SetLocalDate;
    property MenuItem: TMenuItem read FMenuItem write SetMenuItem;
  published
    { Published declarations }
  end;

implementation

function GetPath: string;
begin
  Result := ExtractFilePath(ParamStr(0));
end;

{ TIniContainer }

constructor TIniContainer.create;
begin
  lstBPG := TMyStringList.Create;
  lstDPR := TMyStringList.Create;
  lstPAS := TMyStringList.Create;
  lstDPK := TMyStringList.Create;
  lstOTH := TMyStringList.Create;
  lstFAV := TMyStringList.Create;

  CheckForIni;

  MyIniFile := TMemIniFile.Create(GetPath + 'RecentFiles.ini');

  ReadAll;
end;

procedure TIniContainer.SetDefaultPage(const Value: Integer);
begin
  FDefaultPage := Value;
end;

procedure TIniContainer.SetIgnoreDefaultUnits(const Value: Boolean);
begin
  FIgnoreDefaultUnits := Value;
end;

procedure TIniContainer.SetlstBPG(const Value: TMyStringList);
begin
  FlstBPG := Value;
end;

procedure TIniContainer.SetlstDPK(const Value: TMyStringList);
begin
  FlstDPK := Value;
end;

procedure TIniContainer.SetlstDPR(const Value: TMyStringList);
begin
  FlstDPR := Value;
end;

procedure TIniContainer.SetlstOTH(const Value: TMyStringList);
begin
  FlstOTH := Value;
end;

procedure TIniContainer.SetlstPAS(const Value: TMyStringList);
begin
  FlstPAS := Value;
end;

procedure TIniContainer.SetlstFAV(const Value: TMyStringList);
begin
  FlstFAV := Value;
end;

destructor TIniContainer.Destroy;
begin

  lstBPG.Free;
  lstDPR.Free;
  lstPAS.Free;
  lstDPK.Free;
  lstOTH.Free;
  lstFAV.Free;

end;

procedure TIniContainer.ReadAll;
begin
  if screen <> nil then
    Screen.Cursor := crHourGlass;
  try

    ReadIniFile(nil, 'Capacity');
    ReadIniFile(nil, 'Defaults');
    ReadIniFile(nil, 'Persistance');

    ReadIniFile(lstBPG, 'BPG');
    ReadIniFile(lstDPR, 'DPR');
    ReadIniFile(lstPAS, 'PAS');
    ReadIniFile(lstDPK, 'DPK');
    ReadIniFile(lstOTH, 'Other');
    ReadIniFile(lstFAV, 'FAV');

  finally
    if screen <> nil then Screen.Cursor := crDefault;
  end;
end;

procedure TIniContainer.ReadIniFile(const List: TMyStringList; MySection: string);
var
  i, Left, Top, Height, Width: integer;
  MyStrings: TStringList;
  S, WindowSize: string;
begin

  MyStrings := TStringList.Create;
  try
    if MySection = 'Capacity' then
    begin
      CapacityBPG := MyIniFile.ReadInteger(MySection, 'BPG', 20);
      CapacityDPR := MyIniFile.ReadInteger(MySection, 'DPR', 20);
      CapacityPAS := MyIniFile.ReadInteger(MySection, 'PAS', 20);
      CapacityDPK := MyIniFile.ReadInteger(MySection, 'DPK', 20);
      CapacityOTH := MyIniFile.ReadInteger(MySection, 'Other', 20);
      CapacityFAV := MyIniFile.ReadInteger(MySection, 'FAV', 20);
    end
    else
      if MySection = 'Defaults' then
      begin
        //get the status of Ignoring Default projects and units
        IgnoreDefaultUnits := MyIniFile.ReadBool(MySection, 'IgnoreDefaultUnits', False);
        DefaultPage := MyIniFile.ReadInteger(MySection, 'DefaultPage', 0);
        FormPersistance := MyIniFile.ReadBool(MySection, 'FormPersistance', True);
        SortPersistance := MyIniFile.ReadBool(MySection, 'SortPersistance', False);
        ColumnPersistance := MyIniFile.ReadBool(MySection, 'ColumnPersistance', False);
        LocalDate := MyIniFile.ReadBool(MySection, 'LocalDate', False);
        fShortcut := StrToIntDef(MyIniFile.ReadString(MySection, 'Shortcut', '0'), 0);

        lstBPG.ColumnPersistance := ColumnPersistance;
        lstDPR.ColumnPersistance := ColumnPersistance;
        lstPAS.ColumnPersistance := ColumnPersistance;
        lstDPK.ColumnPersistance := ColumnPersistance;
        lstOTH.ColumnPersistance := ColumnPersistance;
        lstFAV.ColumnPersistance := ColumnPersistance;

        lstBPG.SortPersistance := SortPersistance;
        lstDPR.SortPersistance := SortPersistance;
        lstPAS.SortPersistance := SortPersistance;
        lstDPK.SortPersistance := SortPersistance;
        lstOTH.SortPersistance := SortPersistance;
        lstFAV.SortPersistance := SortPersistance;

      end
      else
        if MySection = 'Persistance' then
        begin
          //get the status of forms and column attribtues

            Height := Screen.Height div 2;
            Width := Screen.Width div 2;
            Top := (Screen.Height - Height) div 2;
            Left := (Screen.Width - Width) div 2;

          WindowSize:= IntToStr(Left)+','+IntToStr(Top)+','+IntToStr(Width)+','+IntToStr(Height);

          FormSize := MyIniFile.ReadString(MySection, 'FormSize', WindowSize);

          lstBPG.ColumnSizes := MyIniFile.ReadString(MySection, 'ColumnSizesBPG', '125,200,120,120');
          lstDPR.ColumnSizes := MyIniFile.ReadString(MySection, 'ColumnSizesDPR', '125,200,120,120');
          lstPAS.ColumnSizes := MyIniFile.ReadString(MySection, 'ColumnSizesPAS', '125,200,120,120');
          lstDPK.ColumnSizes := MyIniFile.ReadString(MySection, 'ColumnSizesDPK', '125,200,120,120');
          lstOTH.ColumnSizes := MyIniFile.ReadString(MySection, 'ColumnSizesOTH', '125,200,120,120');
          lstFAV.ColumnSizes := MyIniFile.ReadString(MySection, 'ColumnSizesFAV', '125,200,120,120');

          lstBPG.ColumnSorting := MyIniFile.ReadString(MySection, 'ColumnSortingBPG', '3,1');
          lstDPR.ColumnSorting := MyIniFile.ReadString(MySection, 'ColumnSortingDPR', '3,1');
          lstPAS.ColumnSorting := MyIniFile.ReadString(MySection, 'ColumnSortingPAS', '3,1');
          lstDPK.ColumnSorting := MyIniFile.ReadString(MySection, 'ColumnSortingDPK', '3,1');
          lstOTH.ColumnSorting := MyIniFile.ReadString(MySection, 'ColumnSortingOTH', '3,1');
          lstFAV.ColumnSorting := MyIniFile.ReadString(MySection, 'ColumnSortingFAV', '3,1');

        end
        else
          with List do
          begin
            Clear;
            MyIniFile.ReadSection(MySection, MyStrings);
            for i := 0 to MyStrings.Count - 1 do
            begin
              S := MyIniFile.ReadString(MySection, 'n' + IntToStr(i), '');
              List.AddTimeObject(copy(S, 1, Pos('|', S) - 1));
              System.delete(S, 1, Pos('|', S));
              List.UpdateTime(List.count - 1, copy(S, 1, Pos('|', S) - 1), '');
              System.delete(S, 1, Pos('|', S));
              List.UpdateTime(List.count - 1, '', copy(S, 1, Pos('|', S) - 1));
            end;
           // sort the list according to time when the file was opened \
           // so we can ensure that we delete the oldest files first
            List.SortByTimeOpened;
          end;
  finally
    MyStrings.Free;
  end;
end;

procedure TIniContainer.WriteIniFile(const List: TMyStringList; Section: string);
var
  i: Integer;
begin
  with List do
  begin
    MyIniFile.EraseSection(Section);
    for i := 0 to Count - 1 do
    begin
      MyIniFile.WriteString(Section, 'n' + IntToStr(i), Strings[i] + '|' + TTimeStorage(List.Objects[i]).fTimeOpen + '|' + TTimeStorage(List.Objects[i]).fTimeClosed + '|');
    end;
  end;
end;

procedure TIniContainer.SaveAll;
begin
  if screen <> nil then
    Screen.Cursor := crHourGlass;
  try
    MyIniFile.EraseSection('Capacity');

    MyIniFile.WriteInteger('Capacity', 'BPG', CapacityBPG);
    MyIniFile.WriteInteger('Capacity', 'DPR', CapacityDPR);
    MyIniFile.WriteInteger('Capacity', 'PAS', CapacityPAS);
    MyIniFile.WriteInteger('Capacity', 'DPK', CapacityDPK);
    MyIniFile.WriteInteger('Capacity', 'Other', CapacityOTH);
    MyIniFile.WriteInteger('Capacity', 'FAV', CapacityFAV);

    MyIniFile.EraseSection('Defaults');

    MyIniFile.WriteBool('Defaults', 'IgnoreDefaultUnits', IgnoreDefaultUnits);
    MyIniFile.WriteInteger('Defaults', 'DefaultPage', DefaultPage);
    MyIniFile.WriteInteger('Defaults', 'Shortcut', fShortcut);

    MyIniFile.WriteBool('Defaults', 'FormPersistance', FormPersistance);
    MyIniFile.WriteBool('Defaults', 'SortPersistance', SortPersistance);
    MyIniFile.WriteBool('Defaults', 'ColumnPersistance', ColumnPersistance);
    MyIniFile.WriteBool('Defaults', 'LocalDate', LocalDate);

    MyIniFile.EraseSection('Persistance');
    MyIniFile.WriteString('Persistance', 'FormSize', FormSize);

    MyIniFile.WriteString('Persistance', 'ColumnSizesBPG', lstBPG.ColumnSizes);
    MyIniFile.WriteString('Persistance', 'ColumnSizesDPR', lstDPR.ColumnSizes);
    MyIniFile.WriteString('Persistance', 'ColumnSizesPAS', lstPAS.ColumnSizes);
    MyIniFile.WriteString('Persistance', 'ColumnSizesDPK', lstDPK.ColumnSizes);
    MyIniFile.WriteString('Persistance', 'ColumnSizesOTH', lstOTH.ColumnSizes);
    MyIniFile.WriteString('Persistance', 'ColumnSizesFAV', lstFAV.ColumnSizes);

    MyIniFile.WriteString('Persistance', 'ColumnSortingBPG', lstBPG.ColumnSorting);
    MyIniFile.WriteString('Persistance', 'ColumnSortingDPR', lstDPR.ColumnSorting);
    MyIniFile.WriteString('Persistance', 'ColumnSortingPAS', lstPAS.ColumnSorting);
    MyIniFile.WriteString('Persistance', 'ColumnSortingDPK', lstDPK.ColumnSorting);
    MyIniFile.WriteString('Persistance', 'ColumnSortingOTH', lstOTH.ColumnSorting);
    MyIniFile.WriteString('Persistance', 'ColumnSortingFAV', lstFAV.ColumnSorting);

    WriteIniFile(lstBPG, 'BPG');
    WriteIniFile(lstDPR, 'DPR');
    WriteIniFile(lstPAS, 'PAS');
    WriteIniFile(lstDPK, 'DPK');
    WriteIniFile(lstOTH, 'Other');
    WriteIniFile(lstFAV, 'FAV');
    MyIniFile.UpdateFile;
  finally
    if screen <> nil then Screen.Cursor := crDefault;
  end;
end;

procedure TIniContainer.CheckForIni;
var
  F: System.Text;
  Path: string;
begin
  Path := GetPath + 'RecentFiles.ini';
  if not FileExists(Path) then
  begin
    System.Assign(F, Path);
    System.Rewrite(F);
    System.Writeln(F, '[Capacity]');
    System.Writeln(F, 'BPG=20');
    System.Writeln(F, 'DPR=20');
    System.Writeln(F, 'PAS=20');
    System.Writeln(F, 'DPK=20');
    System.Writeln(F, 'Other=20');

    System.Writeln(F, '[Defaults]');
    System.Writeln(F, 'IgnoreDefaultUnits=0');
    System.Writeln(F, 'DefaultPage=0');
    System.Writeln(F, 'Shortcut=0');
    System.Writeln(F, 'FormPersistance=1');
    System.Writeln(F, 'SortPersistance=0');
    System.Writeln(F, 'ColumnPersistance=0');
    System.Writeln(F, 'LocalDate=0');

    System.Writeln(F, '[Persistance]');

    System.Writeln(F, 'FormSize=0');

    System.Writeln(F, 'ColumnSizesBPG=0');
    System.Writeln(F, 'ColumnSizesDPR=0');
    System.Writeln(F, 'ColumnSizesPAS=0');
    System.Writeln(F, 'ColumnSizesDPK=0');
    System.Writeln(F, 'ColumnSizesOTH=0');
    System.Writeln(F, 'ColumnSizesFAV=0');

    System.Writeln(F, 'ColumnSortingBPG=0');
    System.Writeln(F, 'ColumnSortingDPR=0');
    System.Writeln(F, 'ColumnSortingPAS=0');
    System.Writeln(F, 'ColumnSortingDPK=0');
    System.Writeln(F, 'ColumnSortingOTH=0');
    System.Writeln(F, 'ColumnSortingFAV=0');

    System.Writeln(F, '[BPG]');
    System.Writeln(F, '[DPR]');
    System.Writeln(F, '[PAS]');
    System.Writeln(F, '[DPK]');
    System.Writeln(F, '[Other]');
    System.Writeln(F, '[FAV]');
    System.Close(F);
  end;
end;

procedure TIniContainer.LogClosingFile(FileName: string);
var
  MyList: TMyStringList;
  i, j: Integer;
  CurrentDateFormat: string;
  LocalDateFormat: string;
begin
  if LocalDate then
    LocalDateFormat := ShortDateFormat + '  '
  else
    LocalDateFormat := 'yyyy-mm-dd  ';

  MyList := GetList(AnsiUpperCase(ExtractFileExt(FileName)));

  //check if file already exists, and if yes, replace the closing time
  if (FileName <> '') then
    if (MyList.Count > 0) then
    begin
      i := MyList.IndexOf(FileName);
      if i = -1 then
      begin
        //ignore Delphi's default ProjectGroup, Project, and Unit, if checked in Options
        if (IgnoreDefaultUnits = False)
          or ((IgnoreDefaultUnits = True)
          and ((Pos('ProjectGroup1', FileName) = 0)
          and (Pos('Project1', FileName) = 0)
          and (Pos('Unit1', FileName) = 0))) then
        begin
          //make sure, we keep only the defined Max # of files
          if MyList.ListCapacity <= MyList.Count then
          begin
            if MyList.Count = MyList.ListCapacity then
            begin
              MyList.Delete(0);
            end
            else
              for j := 0 to (MyList.Count - MyList.ListCapacity) do
              begin
                MyList.Delete(j);
              end;
          end;
        end;
        MyList.AddTimeObject(FileName);
        CurrentDateFormat := ShortDateFormat;
        ShortDateFormat := LocalDateFormat;
        MyList.UpdateTime(MyList.count - 1, '', DateTimeToStr(Now));
        ShortDateFormat := CurrentDateFormat;
      end
      else
      begin
        CurrentDateFormat := ShortDateFormat;
        ShortDateFormat := LocalDateFormat;
        MyList.UpdateTime(i, '', DateTimeToStr(Now));
        ShortDateFormat := CurrentDateFormat;
      end;
    end
    else
    begin
      MyList.AddTimeObject(FileName);
      CurrentDateFormat := ShortDateFormat;
      ShortDateFormat := LocalDateFormat;
      MyList.UpdateTime(0, '', DateTimeToStr(Now));
      ShortDateFormat := CurrentDateFormat;
    end;
  if (AnsiUpperCase(ExtractFileExt(FileName)) = '.BPG') or (AnsiUpperCase(ExtractFileExt(FileName)) = '.DPR') then
  begin
    SaveAll;
  end;
end;

procedure TIniContainer.UpdateIniFile;
begin
  MyIniFile.UpdateFile;
end;

procedure TIniContainer.LogOpenedFile(FileName: string);
var
  i, j: Integer;
  MyList: TMyStringList;
  CurrentDateFormat: string;
  LocalDateFormat: string;
begin
  if LocalDate then
    LocalDateFormat := ShortDateFormat + '  '
  else
    LocalDateFormat := 'yyyy-mm-dd  ';

  MyList := GetList(AnsiUpperCase(ExtractFileExt(FileName)));
  if (FileName <> '') then
    if (MyList.Count > 0) then
    begin
      //check if file already exists, and if yes, replace the opening time
      i := MyList.IndexOf(FileName);
      if i = -1 then
      begin
        //ignore Delphi's default ProjectGroup, Project, and Unit, if checked in Options
        if (IgnoreDefaultUnits = False)
          or ((IgnoreDefaultUnits = True)
          and ((Pos('ProjectGroup1', FileName) = 0)
          and (Pos('Project1', FileName) = 0)
          and (Pos('Unit1', FileName) = 0))) then
        begin
          //make sure, we keep only the defined Max # of files
          if MyList.ListCapacity <= MyList.Count then
          begin
            if MyList.Count = MyList.ListCapacity then
            begin
              MyList.Delete(0);
            end
            else
              for j := 0 to (MyList.Count - MyList.ListCapacity) do
              begin
                MyList.Delete(j);
              end;
          end;

          MyList.AddTimeObject(FileName);
          CurrentDateFormat := ShortDateFormat;
          ShortDateFormat := LocalDateFormat;
          MyList.UpdateTime(MyList.Count - 1, DateTimeToStr(Now), '');
          ShortDateFormat := CurrentDateFormat;
        end;
      end
      else
      begin
        CurrentDateFormat := ShortDateFormat;
        ShortDateFormat := LocalDateFormat;
        MyList.UpdateTime(i, DateTimeToStr(Now), '');
        ShortDateFormat := CurrentDateFormat;
      end;
    end
    else
    begin
      MyList.AddTimeObject(FileName);
      CurrentDateFormat := ShortDateFormat;
      ShortDateFormat := LocalDateFormat;
      MyList.UpdateTime(0, DateTimeToStr(Now), '');
      ShortDateFormat := CurrentDateFormat;
    end;
end;

function TIniContainer.GetList(S: string): TMyStringList;
begin
  if S = '.BPG' then
    Result := lstBPG
  else
    if S = '.DPR' then
      Result := lstDPR
    else
      if S = '.PAS' then
        Result := lstPAS
      else
        if S = '.DPK' then
          Result := lstDPK
        else
          if S = '.FAV' then
            Result := lstFAV
          else
            Result := lstOTH;
end;

procedure TIniContainer.SetCapacityBPG(const Value: Integer);
begin
  FCapacityBPG := Value;
  lstBPG.ListCapacity := Value;
end;

procedure TIniContainer.SetCapacityDPK(const Value: Integer);
begin
  FCapacityDPK := Value;
  lstDPK.ListCapacity := Value;
end;

procedure TIniContainer.SetCapacityDPR(const Value: Integer);
begin
  FCapacityDPR := Value;
  lstDPR.ListCapacity := Value;
end;

procedure TIniContainer.SetCapacityOTH(const Value: Integer);
begin
  FCapacityOTH := Value;
  lstOTH.ListCapacity := Value;
end;

procedure TIniContainer.SetCapacityPAS(const Value: Integer);
begin
  FCapacityPAS := Value;
  lstPAS.ListCapacity := Value;
end;

function TIniContainer.GetCapacityBPG: Integer;
begin
  Result := FCapacityBPG;
end;

function TIniContainer.GetCapacityDPK: Integer;
begin
  Result := FCapacityDPK;
end;

function TIniContainer.GetCapacityDPR: Integer;
begin
  Result := FCapacityDPR;
end;

function TIniContainer.GetCapacityOTH: Integer;
begin
  Result := FCapacityOTH;
end;

function TIniContainer.GetCapacityPAS: Integer;
begin
  Result := FCapacityPAS;
end;

function TIniContainer.GetDefaultPage: Integer;
begin
  Result := FDefaultPage;
end;

function TIniContainer.GetIgnoreDefaultUnits: Boolean;
begin
  Result := FIgnoreDefaultUnits;
end;

function TIniContainer.GetlstBPG: TMyStringList;
begin
  Result := FlstBPG;
end;

function TIniContainer.GetlstDPK: TMyStringList;
begin
  Result := FlstDPK;
end;

function TIniContainer.GetlstDPR: TMyStringList;
begin
  Result := FlstDPR;
end;

function TIniContainer.GetlstOTH: TMyStringList;
begin
  Result := FlstOTH;
end;

function TIniContainer.GetlstPAS: TMyStringList;
begin
  Result := FlstPAS;
end;

function TIniContainer.GetlstFAV: TMyStringList;
begin
  Result := FlstFAV;
end;

function TIniContainer.GetCapacityFAV: Integer;
begin
  Result := FCapacityFAV;
end;

procedure TIniContainer.SetCapacityFAV(const Value: Integer);
begin
  FCapacityFAV := Value;
  lstFAV.ListCapacity := Value;
end;

function TIniContainer.GetColumnPersistance: Boolean;
begin
  Result := FColumnPersistance;
end;

function TIniContainer.GetFormPersistance: Boolean;
begin
  Result := FFormPersistance;
end;

function TIniContainer.GetSortPersistance: Boolean;
begin
  Result := FSortPersistance;
end;

procedure TIniContainer.SetColumnPersistance(const Value: Boolean);
begin
  FColumnPersistance := Value;
end;

procedure TIniContainer.SetFormPersistance(const Value: Boolean);
begin
  FFormPersistance := Value;
end;

procedure TIniContainer.SetSortPersistance(const Value: Boolean);
begin
  FSortPersistance := Value;
end;

procedure TIniContainer.SetFormSize(const Value: string);
begin
  FFormSize := Value;
end;

function TIniContainer.GetFormSize: string;
begin
  Result := FFormSize;
end;

function TIniContainer.GetShortcut: TShortcut;
begin
  Result := fShortcut;
end;

procedure TIniContainer.SetShortcut(Value: TShortcut);
begin
  fShortcut := Value;
  if FMenuItem <> nil then
  begin
    FMenuItem.Shortcut := Value;
  end;
end;

procedure TIniContainer.SetMenuItem(const Value: TMenuItem);
begin
  FMenuItem := Value;
  if Value <> nil then
  begin
    Value.Shortcut := fShortcut;
  end;
end;

function TIniContainer.GetLocalDate: Boolean;
begin
  Result := FLocalDate;
end;

procedure TIniContainer.SetLocalDate(const Value: Boolean);
begin
  FLocalDate := Value;
end;

end.

