{-----------------------------------------------------------------------------
JEDI File Re-Opener

   Source file dOptions.pas

The contents of this file are subject to the Mozilla Public License
Version 1.1 (the "License"); you may not use this file except in compliance
with the License. You may obtain a copy of the License at
http://www.mozilla.org/NPL/NPL-1_1Final.html

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either expressed or implied. See the License for
the specific language governing rights and limitations under the License.

Original Developer: Michael Beck <mbeck@bigfoot.com>
http://www.geocities.com/beckmi/delphi.htm

Contributors: Robert Cerny [robert.cerny@neosys.xrs.si]

Last Modified: 2001-02-15
Current Version: 1.52

You may retrieve the latest version of this file at the Project JEDI home page,
located at http://www.delphi-jedi.org

Known Issues:
-----------------------------------------------------------------------------}
unit dOptions;

interface

uses Windows, SysUtils, Classes, Graphics, Forms, Controls, StdCtrls,
  Buttons, ExtCtrls, Spin, inifiles, ComCtrls,
  jvReopenerInterfaces
  ;

type
  TdlgOptions = class(TForm, IOptionsMemento)
    btnOK: TBitBtn;
    btnCancel: TBitBtn;
    tvTreeView1: TTreeView;
    nbOptions: TNotebook;
    GroupBox1: TGroupBox;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    SpinEditBPG: TSpinEdit;
    SpinEditDPR: TSpinEdit;
    SpinEditPAS: TSpinEdit;
    SpinEditDPK: TSpinEdit;
    SpinEditOther: TSpinEdit;
    SpinEditFAV: TSpinEdit;

    GroupBox2: TGroupBox;
    Label6: TLabel;
    chkIgnoreDefault: TCheckBox;
    cbDefaultPage: TComboBox;
    lblLabel7: TLabel;
    chkFormPersistance: TCheckBox;
    chkColumnPersistance: TCheckBox;
    chkSortPersistance: TCheckBox;
    chkLocalDate: TCheckBox;
    hkMenu: THotKey;
    Label7: TLabel;


    procedure SpinEditBPGExit(Sender: TObject);
    procedure tvTreeView1Change(Sender: TObject; Node: TTreeNode);
    procedure FormShow(Sender: TObject);
    procedure btnOKClick(Sender: TObject);
    procedure btnCancelClick(Sender: TObject);
  private
    { Private declarations }
    FMyIniContainer: IOptionsMemento;

  public
    { Public declarations }
    constructor Create(AOwner: TComponent; IniContainer: IOptionsMemento); reintroduce; overload;
    procedure GetMemento;
    procedure SetMemento;
    property MyIniContainer: IOptionsMemento read FMyIniContainer write FMyIniContainer implements IOptionsMemento;

  end;

var
  dlgOptions        : TdlgOptions;

implementation

{$R *.DFM}

uses jvFileReopener, fFilesList;

procedure TdlgOptions.SpinEditBPGExit(Sender: TObject);
begin
  if TSpinEdit(sender).value < 1 then TSpinEdit(sender).value := 1;
end;

procedure TdlgOptions.tvTreeView1Change(Sender: TObject; Node: TTreeNode);
begin

  nbOptions.PageIndex := Node.Index;

end;

procedure TdlgOptions.FormShow(Sender: TObject);
begin
  self.ActiveControl := tvTreeView1;
  tvTreeView1.Items[0].Selected := True;
  SetWindowPos((self).Handle, HWND_TOPMOST, 0, 0, 0, 0, SWP_NOACTIVATE or SWP_NOMOVE or SWP_NOSIZE);
end;

constructor TdlgOptions.Create(AOwner: TComponent; IniContainer: IOptionsMemento);
begin
  self.Create(AOwner);
  MyIniContainer := IniContainer;
  MyIniContainer._AddRef; //increase reference count
end;

procedure TdlgOptions.btnOKClick(Sender: TObject);
begin
  ModalResult := mrOK;
end;

procedure TdlgOptions.GetMemento;
begin
  MyIniContainer.CapacityBPG := SpinEditBPG.Value;
  MyIniContainer.CapacityDPR := SpinEditDPR.Value;
  MyIniContainer.CapacityPAS := SpinEditPAS.Value;
  MyIniContainer.CapacityDPK := SpinEditDPK.Value;
  MyIniContainer.CapacityOTH := SpinEditOther.Value;
  MyIniContainer.CapacityFAV := SpinEditFAV.Value;

  MyIniContainer.IgnoreDefaultUnits := chkIgnoreDefault.Checked;
  MyIniContainer.DefaultPage := cbDefaultPage.ItemIndex;

  MyIniContainer.FormPersistance := chkFormPersistance.Checked;
  MyIniContainer.ColumnPersistance := chkColumnPersistance.Checked;
  MyIniContainer.SortPersistance := chkSortPersistance.Checked;

  MyIniContainer.Shortcut := hkMenu.Hotkey;
  MyIniContainer.LocalDate := chkLocalDate.Checked;

end;

procedure TdlgOptions.SetMemento;
begin
  SpinEditBPG.Value := MyIniContainer.CapacityBPG;
  SpinEditDPR.Value := MyIniContainer.CapacityDPR;
  SpinEditPAS.Value := MyIniContainer.CapacityPAS;
  SpinEditDPK.Value := MyIniContainer.CapacityDPK;
  SpinEditOther.Value := MyIniContainer.CapacityOTH;
  SpinEditFAV.Value := MyIniContainer.CapacityFAV;

  chkIgnoreDefault.Checked := MyIniContainer.IgnoreDefaultUnits;
  cbDefaultPage.ItemIndex := MyIniContainer.DefaultPage;

  chkFormPersistance.Checked := MyIniContainer.FormPersistance;
  chkColumnPersistance.Checked := MyIniContainer.ColumnPersistance;
  chkSortPersistance.Checked := MyIniContainer.SortPersistance;

  hkMenu.Hotkey := MyIniContainer.Shortcut;
  chkLocalDate.Checked:= MyIniContainer.LocalDate;

end;

procedure TdlgOptions.btnCancelClick(Sender: TObject);
begin
  ModalResult := mrCancel;
end;

end.

