{-----------------------------------------------------------------------------
JEDI File Re-Opener

   Source file fFilesList.pas

The contents of this file are subject to the Mozilla Public License
Version 1.1 (the "License"); you may not use this file except in compliance
with the License. You may obtain a copy of the License at
http://www.mozilla.org/NPL/NPL-1_1Final.html

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either expressed or implied. See the License for
the specific language governing rights and limitations under the License.

Original Developer: Michael Beck <mbeck@bigfoot.com>
http://www.geocities.com/beckmi/delphi.htm

Contributors: Jesper Hogstrom <jesper.hogstrom@boldsoft.com>
              John Emery <john@profitstar.com>
              Bruce <51831234@3web.net>

Last Modified: 2001-02-21
Current Version: 1.54

You may retrieve the latest version of this file at the Project JEDI home page,
located at http://www.delphi-jedi.org

Known Issues:
-----------------------------------------------------------------------------}
unit fFilesList;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons, frFileList, ComCtrls, ExtCtrls, inifiles, ImgList, dOptions,
  ToolWin, IniContainer, jvReopenerInterfaces, jvReopenerClasses;

type

  TRecentFileType = (rfBPG, rfDPR, rfPAS, rfDPK, rfOther);

  TJvFilesListForm = class(TForm, IReopenerFiles, IOptionsMemento)
    ilProjectImages: TImageList;
    ToolBar1: TToolBar;
    btnOpen: TToolButton;
    btnExit: TToolButton;
    btnDelete: TToolButton;
    tbsSeparator4: TToolButton;
    btnOptions: TToolButton;
    tbsSeparator6: TToolButton;
    btnAbout: TToolButton;
    tbsSeparator8: TToolButton;
    TreeView1: TTreeView;
    tbsSeparator9: TToolButton;
    Splitter1: TSplitter;
    nbkFiles: TNotebook;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    frBPG: TjvRecentFilesFrame;
    frDPR: TjvRecentFilesFrame;
    frPAS: TjvRecentFilesFrame;
    frDPK: TjvRecentFilesFrame;
    frOTH: TjvRecentFilesFrame;
    ilStandardImages: TImageList;
    frFAV: TjvRecentFilesFrame;
    btnFavorite: TToolButton;
    tbtnToolButton1: TToolButton;
    procedure btnExitClick(Sender: TObject);
    procedure btnOpenClick(Sender: TObject);
    procedure btnOptionsClick(Sender: TObject);
    procedure btnDeleteClick(Sender: TObject);
    procedure btnAboutClick(Sender: TObject);
    procedure TreeView1Change(Sender: TObject; Node: TTreeNode);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure FormDestroy(Sender: TObject);
    procedure TreeView1DragOver(Sender, Source: TObject; X, Y: Integer;
      State: TDragState; var Accept: Boolean);
    procedure TreeView1DragDrop(Sender, Source: TObject; X, Y: Integer);
    procedure btnFavoriteClick(Sender: TObject);
    procedure FormShow(Sender: TObject);

  private
    { Private declarations }
//    FIgnoreDefaultUnits: Boolean;
//    FDefaultPage: Integer;
    FMyIniContainer: IReopenerFiles;
    FActiveFrame: TjvRecentFilesFrame;
    FMyOptionsMemento: IOptionsMemento;
    procedure ReadIniFile(const ListView: TListView; MySection: string);
    procedure SetMyIniContainer(const Value: IReopenerFiles);
    procedure SetActiveFrame(const Value: TjvRecentFilesFrame);
    procedure SetMyOptionsMemento(const Value: IOptionsMemento);
    procedure AddToFavorites(Source: TListView);

  public
    { Public declarations }
    property MyIniContainer: IReopenerFiles read FMyIniContainer write SetMyIniContainer implements IReopenerFiles;
    property MyOptionsMemento: IOptionsMemento read FMyOptionsMemento write SetMyOptionsMemento implements IOptionsMemento;

    property ActiveFrame: TjvRecentFilesFrame read FActiveFrame write SetActiveFrame;

    constructor create(const AOwner: TComponent; IniContainer: IReopenerFiles; Options: IOptionsMemento); reintroduce; overload;
    destructor destroy; override;
  end;

var
  JvFilesListForm: TJvFilesListForm;

implementation

{$R *.DFM}

uses ToolsAPI, fAboutMe
  //    , RzCSIntf
  ;

var
  FilesListSingleton: TJvFilesListForm;

procedure TJvFilesListForm.btnExitClick(Sender: TObject);
begin
  self.Close;
end;

procedure TJvFilesListForm.btnOpenClick(Sender: TObject);
begin
  if ActiveFrame.ListView1.SelCount > 0 then
    ActiveFrame.OpenSelectedItems;
end;

procedure TJvFilesListForm.btnOptionsClick(Sender: TObject);
var
  dlgOptions: TdlgOptions;
begin
  dlgOptions := TdlgOptions.create(self, MyOptionsMemento);
  try
    dlgOptions.SetMemento;
    if dlgOptions.ShowModal = mrOK then
    begin
      dlgOptions.GetMemento;
    end;
  finally
    dlgOptions.Free;
  end;
end;

procedure TJvFilesListForm.btnDeleteClick(Sender: TObject);
begin
  if ActiveFrame.ListView1.SelCount > 0 then
    ActiveFrame.DeleteSelectedItems;

end;

procedure TJvFilesListForm.ReadIniFile(const ListView: TListView; MySection: string);
var
  i, j, myLeft, myTop, myHeight, myWidth: integer;
  S: string;
  MyList: TMyStringList;
  MyArray: array[1..4] of integer;

begin
  if MySection = 'Persistance' then
  begin
    with Self do
    begin
      j := 0;
      S := MyIniContainer.FormSize;
      if S = '0' then
      begin
        myHeight := Screen.Height div 2;
        myWidth := Screen.Width div 2;
        myTop := (Screen.Height - Height) div 2;
        myLeft := (Screen.Width - Width) div 2;
        S := IntToStr(myLeft) + ',' + IntToStr(myTop) + ',' + IntToStr(myWidth) + ',' + IntToStr(myHeight);
      end;

      for i := 1 to 4 do
      begin
        try
          j := Pos(',', s);
          if j = 0 then
            j := Length(s) + 1;
          MyArray[i] := StrToIntDef(Copy(s, 1, j - 1), 0);
        except
          { Nothing, just eat the exception };
        end;
        s := copy(s, j + 1, length(s));
        if s = '' then break;
      end;
      Top := MyArray[1];
      Left := MyArray[2];
      Height := MyArray[3];
      Width := MyArray[4];
    end;
  end
  else
    with ListView do
    begin
      Items.Clear;
      MyList := MyIniContainer.GetList('.' + MySection);
      for i := 0 to MyList.Count - 1 do
      begin
        S := MyList.Strings[i];
        with ListView.Items.Add do
        begin
          Caption := ExtractFileName(S);
          SubItems.Add(ExtractFilePath(S));
          if TTimeStorage(MyList.Objects[i]).fTimeOpen <> '' then
            SubItems.Add(TTimeStorage(MyList.Objects[i]).fTimeOpen)
          else
            SubItems.Add(' ');
          if TTimeStorage(MyList.Objects[i]).fTimeClosed <> '' then
            SubItems.Add(TTimeStorage(MyList.Objects[i]).fTimeClosed)
          else
            SubItems.Add(' ');
        end;
      end;
    end;
end;

procedure TJvFilesListForm.btnAboutClick(Sender: TObject);
var
  AboutBox: TAboutBox;
begin

  AboutBox := TAboutBox.Create(Self);
  AboutBox.ShowModal;
  AboutBox.free;

end;

procedure TJvFilesListForm.TreeView1Change(Sender: TObject;
  Node: TTreeNode);
begin
  btnDelete.Enabled := False;
  btnOpen.Enabled := False;
  btnFavorite.Enabled := False;

  case Node.Index of
    0:
      begin
        if Node <> TreeView1.TopItem then
        begin
          nbkFiles.ActivePage := 'ProjectGroup';
          ActiveFrame := frBPG;
        end;
      end;
    1:
      begin
        nbkFiles.ActivePage := 'Project';
        ActiveFrame := frDPR;
      end;
    2:
      begin
        nbkFiles.ActivePage := 'Pascal';
        ActiveFrame := frPAS;
      end;
    3:
      begin
        nbkFiles.ActivePage := 'Package';
        ActiveFrame := frDPK;
      end;
    4:
      begin
        nbkFiles.ActivePage := 'Other';
        ActiveFrame := frOTH;
      end;
    5:
      begin
        nbkFiles.ActivePage := 'Favorites';
        ActiveFrame := frFAV;
      end;
  end;
  if ActiveFrame.ListView1.SelCount > 0 then
  begin
    btnDelete.Enabled := True;
    btnOpen.Enabled := True;
    btnFavorite.Enabled := True;

  end;

end;

constructor TJvFilesListForm.create(const AOwner: TComponent; IniContainer: IReopenerFiles; Options: IOptionsMemento);
begin
  if FilesListSingleton <> nil then //check for Singleton condition
  begin
    SetWindowPos((FilesListSingleton).Handle, HWND_TOP, 0, 0, 0, 0, SWP_NOMOVE or SWP_NOSIZE);
    Abort;
  end
  else
  begin
    inherited Create(AOwner);
    FilesListSingleton := Self;

    MyIniContainer := IniContainer;
    MyOptionsMemento := Options;

    MyIniContainer._AddRef; //increase reference count

    ReadIniFile(nil, 'Persistance');

    ReadIniFile(frBPG.ListView1, 'BPG');
    ReadIniFile(frDPR.ListView1, 'DPR');
    ReadIniFile(frPAS.ListView1, 'PAS');
    ReadIniFile(frDPK.ListView1, 'DPK');
    ReadIniFile(frOTH.ListView1, 'Other');
    ReadIniFile(frFAV.ListView1, 'FAV');

    frBPG.btnDelete := btnDelete; frBPG.btnOpen := btnOpen; frBPG.btnFavorite := btnFavorite; frBPG.MyStringList := MyIniContainer.lstBPG;
    frDPR.btnDelete := btnDelete; frDPR.btnOpen := btnOpen; frDPR.btnFavorite := btnFavorite; frDPR.MyStringList := MyIniContainer.lstDPR;
    frPAS.btnDelete := btnDelete; frPAS.btnOpen := btnOpen; frPAS.btnFavorite := btnFavorite; frPAS.MyStringList := MyIniContainer.lstPAS;
    frDPK.btnDelete := btnDelete; frDPK.btnOpen := btnOpen; frDPK.btnFavorite := btnFavorite; frDPK.MyStringList := MyIniContainer.lstDPK;
    frOTH.btnDelete := btnDelete; frOTH.btnOpen := btnOpen; frOTH.btnFavorite := btnFavorite; frOTH.MyStringList := MyIniContainer.lstOTH;
    frFAV.btnDelete := btnDelete; frFAV.btnOpen := btnOpen; frFAV.btnFavorite := btnFavorite; frFAV.MyStringList := MyIniContainer.lstFAV;

    if MyIniContainer.ColumnPersistance then
    begin
      frBPG.GetColumnMemento;
      frDPR.GetColumnMemento;
      frPAS.GetColumnMemento;
      frDPK.GetColumnMemento;
      frOTH.GetColumnMemento;
      frFAV.GetColumnMemento;
    end;

    if MyIniContainer.SortPersistance then
    begin

      frDPR.GetSortMemento;
      frBPG.GetSortMemento;
      frPAS.GetSortMemento;
      frDPK.GetSortMemento;
      frOTH.GetSortMemento;
      frFAV.GetSortMemento;

    end;

    TreeView1.FullExpand;
    TreeView1.Items[MyOptionsMemento.DefaultPage + 1].Selected := True;

    frFAV.ListView1.DragMode := dmManual;

  end;
end;

procedure TJvFilesListForm.SetMyIniContainer(const Value: IReopenerFiles);
begin
  FMyIniContainer := Value;
end;

procedure TJvFilesListForm.SetActiveFrame(const Value: TjvRecentFilesFrame);
begin
  FActiveFrame := Value;
end;

destructor TJvFilesListForm.destroy;
begin
  if FilesListSingleton = Self then
    FilesListSingleton := nil;
  inherited;
end;

procedure TJvFilesListForm.FormClose(Sender: TObject; var Action: TCloseAction);
var
  FormSize: string;
begin
  FormSize := '';

  if MyIniContainer.FormPersistance then
    with Self do
    begin
      FormSize := IntToStr(Top) + ',' + IntToStr(Left) + ',' + IntToStr(Height) + ',' + IntToStr(Width);
      MyIniContainer.FormSize := FormSize;
    end;

  if MyIniContainer.ColumnPersistance then
  begin
    frBPG.SetColumnMemento;
    frDPR.SetColumnMemento;
    frPAS.SetColumnMemento;
    frDPK.SetColumnMemento;
    frOTH.SetColumnMemento;
    frFAV.SetColumnMemento;
  end;

  if MyIniContainer.SortPersistance then
  begin
    frBPG.SetSortMemento;
    frDPR.SetSortMemento;
    frPAS.SetSortMemento;
    frDPK.SetSortMemento;
    frOTH.SetSortMemento;
    frFAV.SetSortMemento;
  end;

  Action := caFree;
end;

procedure TJvFilesListForm.FormDestroy(Sender: TObject);
begin
  MyIniContainer.SaveAll;
end;

procedure TJvFilesListForm.SetMyOptionsMemento(const Value: IOptionsMemento);
begin
  FMyOptionsMemento := Value;
end;

procedure TJvFilesListForm.TreeView1DragOver(Sender, Source: TObject; X,
  Y: Integer; State: TDragState; var Accept: Boolean);
begin
  if TreeView1.GetNodeAt(X, Y) = nil then
    Accept := False
  else
    if (TTreeNode(TreeView1.GetNodeAt(X, Y)).Text = 'Favorites') and (Source is TListView) then
      Accept := True
    else
      Accept := False;
end;

procedure TJvFilesListForm.TreeView1DragDrop(Sender, Source: TObject; X, Y: Integer);
begin
  if (TTreeNode(TreeView1.GetNodeAt(X, Y)).Text = 'Favorites') and (Source is TListView) then
    AddToFavorites(Source as TListView);

end;

procedure TJvFilesListForm.btnFavoriteClick(Sender: TObject);
begin
  if ActiveFrame.ListView1.SelCount > 0 then
    AddToFavorites(ActiveFrame.ListView1);
end;

procedure TJvFilesListForm.AddToFavorites(Source: TListView);
var
  j, Index: Integer;
  MyList: TMyStringList;
  DroppedFile: string;
begin
  MyList := frFAV.MyStringList;
  DroppedFile := TListView(Source).Selected.SubItems[0] + TListView(Source).Selected.Caption;

  Index := MyList.IndexOf(DroppedFile);
  if Index = -1 then
  begin
    if (MyList.Count > 0) then
    begin
      //make sure, we keep only the defined Max # of files
      if MyList.ListCapacity <= MyList.Count then
      begin
        if MyList.Count = MyList.ListCapacity then
        begin
          MyList.Delete(0);
        end
        else
          for j := 0 to (MyList.Count - MyList.ListCapacity) do
          begin
            MyList.Delete(j);
          end;
      end;
      MyList.AddTimeObject(DroppedFile);
      with frFAV.ListView1.Items.Add do
      begin
        Caption := TListView(Source).Selected.Caption;
        SubItems.Add(TListView(Source).Selected.SubItems[0]);
      end;
    end
    else
    begin
      MyList.AddTimeObject(DroppedFile);
      with frFAV.ListView1.Items.Add do
      begin
        Caption := TListView(Source).Selected.Caption;
        SubItems.Add(TListView(Source).Selected.SubItems[0]);
      end;
    end;
  end;
end;

procedure TJvFilesListForm.FormShow(Sender: TObject);
begin
  Self.ActiveControl := ActiveFrame.ListView1;
if ActiveFrame.ListView1.Items.Count >  0 then
begin
  ActiveFrame.ListView1.SetFocus;
  ActiveFrame.ListView1.Items[0].Selected := True;
  ActiveFrame.ListView1.Items[0].Focused := True;
end;
end;

initialization
  // Initialize the global Singleton variable to nil:
  FilesListSingleton := nil;

finalization
  // Free the reference:
  FilesListSingleton.Free;
end.

