{-----------------------------------------------------------------------------
JEDI File Re-Opener

   Source file frFileList.pas

The contents of this file are subject to the Mozilla Public License
Version 1.1 (the "License"); you may not use this file except in compliance
with the License. You may obtain a copy of the License at
http://www.mozilla.org/NPL/NPL-1_1Final.html

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either expressed or implied. See the License for
the specific language governing rights and limitations under the License.

Original Developer: Michael Beck <mbeck@bigfoot.com>
http://www.geocities.com/beckmi/delphi.htm

Contributors: John Emery <john@profitstar.com>

Last Modified: 2001-02-21
Current Version: 1.53

You may retrieve the latest version of this file at the Project JEDI home page,
located at http://www.delphi-jedi.org

Known Issues:
-----------------------------------------------------------------------------}
unit frFileList;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ComCtrls, buttons, IniContainer, jvReopenerClasses;

type
  TjvRecentFilesFrame = class(TFrame)
    ListView1: TListView;
    procedure ListView1ColumnClick(Sender: TObject; Column: TListColumn);
    procedure ListView1Compare(Sender: TObject; Item1, Item2: TListItem; Data: Integer; var Compare: Integer);
    procedure ListView1KeyUp(Sender: TObject; var Key: Word; Shift: TShiftState);
    procedure ListView1DblClick(Sender: TObject);
    procedure ListView1SelectItem(Sender: TObject; Item: TListItem; Selected: Boolean);
  private
    FSortOrder: Integer;
    FColumnToSort: Integer;
    procedure SetColumnToSort(const Value: Integer);
    procedure SetSortOrder(const Value: Integer);
  private
    { Private declarations }
    FbtnOpen: TToolButton;
    FbtnDelete: TToolButton;
    FMyStringList: TMyStringList;
    FbtnFavorite: TToolButton;

    procedure SetbtnDelete(const Value: TToolButton);
    procedure SetbtnOpen(const Value: TToolButton);
    procedure SetMyStringList(const Value: TMyStringList);
    procedure SetbtnFavorite(const Value: TToolButton);
    property ColumnToSort: Integer read FColumnToSort write SetColumnToSort;
    property SortOrder: Integer read FSortOrder write SetSortOrder;
  public
    { Public declarations }
    procedure DeleteSelectedItems;
    procedure OpenSelectedItems;
    procedure OpenSelectedItem;
    procedure GetColumnMemento;
    procedure GetSortMemento;
    procedure SetSortMemento;
    procedure SetColumnMemento;

    property btnDelete: TToolButton read FbtnDelete write SetbtnDelete;
    property btnOpen: TToolButton read FbtnOpen write SetbtnOpen;
    property btnFavorite: TToolButton read FbtnFavorite write SetbtnFavorite;
    property MyStringList: TMyStringList read FMyStringList write SetMyStringList;

  end;

implementation

{$R *.DFM}

uses ToolsAPI
  //  , RzCSIntf
  ;

procedure TjvRecentFilesFrame.ListView1ColumnClick(Sender: TObject; Column: TListColumn);
begin
  ColumnToSort := Column.Index;
  if Column.Tag = 0 then
    Column.Tag := 1
  else
    Column.Tag := 0;
  SortOrder := Column.Tag;

  ListView1.AlphaSort;
end;

procedure TjvRecentFilesFrame.ListView1Compare(Sender: TObject; Item1,
  Item2: TListItem; Data: Integer; var Compare: Integer);
var
  ix: Integer;
begin
  if ColumnToSort = 0 then
  begin
    if SortOrder = 0 then
      Compare := CompareText(Item1.Caption, Item2.Caption)
    else
      Compare := CompareText(Item2.Caption, Item1.Caption)
  end
  else
  begin
    ix := ColumnToSort - 1;
    if SortOrder = 0 then
      Compare := CompareText(Item1.SubItems[ix], Item2.SubItems[ix])
    else
      Compare := CompareText(Item2.SubItems[ix], Item1.SubItems[ix])
  end;
end;

procedure TjvRecentFilesFrame.ListView1KeyUp(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  if (Key = VK_DELETE) and (ListView1.Selected <> nil) then
  begin
    if ListView1.SelCount > 0 then
    begin
      DeleteSelectedItems;
    end
    else
      MessageDlg('Please select a file', mtError, [mbOK], 0);
  end;

  if (Key = VK_RETURN) then
    if ListView1.SelCount > 0 then
      OpenSelectedItems;
end;

procedure TjvRecentFilesFrame.ListView1DblClick(Sender: TObject);
begin
  if ListView1.SelCount > 0 then
    OpenSelectedItem;
end;

procedure TjvRecentFilesFrame.DeleteSelectedItems;
var
  i, index: integer;
begin
  if ListView1.SelCount > 1 then
  begin
    for i := ListView1.Items.Count - 1 downto 0 do
      if ListView1.Items[i].Selected then
      begin
        Index := MyStringList.IndexOf(ListView1.Items[i].SubItems[0] + ListView1.Items[i].Caption);
        if Index > -1 then MyStringList.Delete(Index);
        ListView1.Items.Delete(i);
      end;
  end
  else
  begin
    // this is mainly for continous deleting with the Del key
    i := ListView1.selected.Index;
    Index := MyStringList.IndexOf(ListView1.Selected.SubItems[0] + ListView1.Selected.Caption);
    if Index > -1 then MyStringList.Delete(Index);
    ListView1.Selected.Delete;
    // select the item below the deleted one
    if ListView1.Items.Count > i then
      ListView1.Items.Item[i].Selected := True
        // if the deleted item is the last one, and the list is not empty,
// select string above the deleted one
    else
      if (ListView1.Items.Count = i) and (i > 0) then
        ListView1.Items.Item[i - 1].Selected := True;
  end;
end;

procedure TjvRecentFilesFrame.OpenSelectedItems;
var
  i: integer;
begin
  if ListView1.SelCount > 1 then
  begin
    for i := ListView1.Items.Count - 1 downto 0 do
      if ListView1.Items[i].Selected then
        if FileExists(ListView1.Items[i].SubItems[0] + ListView1.Items[i].Caption) then
          (BorlandIDEServices as IOTAActionServices).OpenFile(ListView1.Items[i].SubItems[0] + ListView1.Items[i].Caption);
    if (Self.Name = 'frBPG') or (Self.Name = 'frDPR') then
      TForm(Self.Owner).Close
    else
      SetWindowPos((TForm(Self.Owner).Handle), HWND_TOP, 0, 0, 0, 0, SWP_NOMOVE or SWP_NOSIZE);
  end
  else
    OpenSelectedItem;
end;

procedure TjvRecentFilesFrame.OpenSelectedItem;
begin
  if FileExists(ListView1.Selected.SubItems[0] + ListView1.Selected.Caption) then
    (BorlandIDEServices as IOTAActionServices).OpenFile(ListView1.Selected.SubItems[0] + ListView1.Selected.Caption);
    if (Self.Name = 'frBPG') or (Self.Name = 'frDPR') then
      TForm(Self.Owner).Close
    else
  SetWindowPos((TForm(Self.Owner).Handle), HWND_TOP, 0, 0, 0, 0, SWP_NOMOVE or SWP_NOSIZE);
end;

procedure TjvRecentFilesFrame.ListView1SelectItem(Sender: TObject;
  Item: TListItem; Selected: Boolean);
begin

  if btnDelete <> nil then btnDelete.Enabled := True;
  if btnOpen <> nil then btnOpen.Enabled := True;
  if btnFavorite <> nil then btnFavorite.Enabled := True;

end;

procedure TjvRecentFilesFrame.SetbtnDelete(const Value: TToolButton);
begin
  FbtnDelete := Value;
end;

procedure TjvRecentFilesFrame.SetbtnOpen(const Value: TToolButton);
begin
  FbtnOpen := Value;
end;

procedure TjvRecentFilesFrame.SetMyStringList(const Value: TMyStringList);
begin
  FMyStringList := Value;
end;

procedure TjvRecentFilesFrame.SetbtnFavorite(const Value: TToolButton);
begin
  FbtnFavorite := Value;
end;

procedure TjvRecentFilesFrame.GetColumnMemento;
var
  S: string;
  i, j: Integer;
begin
  if MyStringList.ColumnPersistance then
  begin
    j := 0;
    S := MyStringList.ColumnSizes;
    for i := 0 to ListView1.Columns.Count - 1 do
    begin
      try
        j := Pos(',', s);
        if j = 0 then
          j := Length(s) + 1;
        ListView1.Column[i].Width := StrToIntDef(Copy(s, 1, j - 1), 0);
      except
        { Nothing };
      end;
      s := copy(s, j + 1, length(s));
      if s = '' then break;
    end;
  end;
end;

procedure TjvRecentFilesFrame.GetSortMemento;
var
  S: string;
  j: Integer;
begin
  if MyStringList.SortPersistance then
  begin
    S := MyStringList.ColumnSorting;
    j := Pos(',', s);
    if j = 0 then
      j := Length(s) + 1;
    ColumnToSort := StrToIntDef(Copy(s, 1, j - 1), 1);
    s := copy(s, j + 1, length(s));
    SortOrder := StrToIntDef(S, 1);

    //Now sort the columns
    ListView1.AlphaSort;
  end;
end;

procedure TjvRecentFilesFrame.SetColumnMemento;
var
  S: string;
  i: Integer;
begin
  if MyStringList.ColumnPersistance then
  begin

    if ListView1.Columns.Count < 1 then exit;
    s := '';
    for i := 0 to ListView1.Columns.Count - 1 do
      s := s + IntToStr(ListView1.Column[i].Width) + ',';
    SetLength(s, Length(s) - 1);
    MyStringList.ColumnSizes := S;
  end;

end;

procedure TjvRecentFilesFrame.SetSortMemento;
begin
  if MyStringList.SortPersistance then
    MyStringList.ColumnSorting := IntToStr(ColumnToSort) + ',' + IntToStr(SortOrder);
end;

procedure TjvRecentFilesFrame.SetColumnToSort(const Value: Integer);
begin
  FColumnToSort := Value;
end;

procedure TjvRecentFilesFrame.SetSortOrder(const Value: Integer);
begin
  FSortOrder := Value;
end;

end.

