{-----------------------------------------------------------------------------
JEDI File Re-Opener

   Source file jvFileReopener.pas

The contents of this file are subject to the Mozilla Public License
Version 1.1 (the "License"); you may not use this file except in compliance
with the License. You may obtain a copy of the License at
http://www.mozilla.org/NPL/NPL-1_1Final.html

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either expressed or implied. See the License for
the specific language governing rights and limitations under the License.

Original Developer: Michael Beck <mbeck@bigfoot.com>
http://www.geocities.com/beckmi/delphi.htm

Contributors: Jesper Hogstrom <jesper.hogstrom@boldsoft.com>
              Robert Cerny <robert.cerny@neosys.xrs.si>

Last Modified: 2001-02-15
Current Version: 1.52

You may retrieve the latest version of this file at the Project JEDI home page,
located at http://www.delphi-jedi.org

Known Issues:
-----------------------------------------------------------------------------}
unit jvFileReopener;

interface

uses Windows, Forms, classes, Menus, ToolsAPI, fFilesList, inifiles, IniContainer;

type

  TJvFileReopener = class(TNotifierObject, IOTAWizard, IOTANotifier, IOTAIDENotifier)

  private

    FMainMenu: TMainMenu;
    FFileMenu: TMenuItem;
    FReopenMenuItem: TMenuItem;
    FNewMenuItem: TMenuItem;
    FMyIniContainer: TIniContainer;

    procedure SetMyIniContainer(const Value: TIniContainer);
  protected

    // IOTAWizard methods

    function GetIDString: string;
    function GetName: string;
    function GetState: TWizardState;
    procedure Execute;

    //IOTAIDENotifier methods

    { This procedure is called for many various file operations within the IDE }
    procedure FileNotification(NotifyCode: TOTAFileNotification; const FileName: string; var Cancel: Boolean);
    { This function is called immediatately before the compiler is invoked.
      Set Cancel to True to cancel the compile }
    procedure BeforeCompile(const Project: IOTAProject; var Cancel: Boolean); overload;
    { This procedure is called immediately following a compile.  Succeeded
      will be true if the compile was successful }
    procedure AfterCompile(Succeeded: Boolean); overload;

  public
    constructor Create;
    destructor Destroy; override;
    procedure OpenRecentFiles(Sender: TObject);
    property MyIniContainer: TIniContainer read FMyIniContainer write SetMyIniContainer;
  end;

procedure Register;

//var RecentFilesArray: array of String;

implementation

uses SysUtils, Controls, frFileList, comctrls, jvReopenerInterfaces;

var
  Index             : Integer;

procedure Register;
begin
  Index := (BorlandIDEServices as IOTAServices).AddNotifier(TJvFileReopener.Create);
end;

// Modified by Erik Berry from code posted by Ray Lischner (www.tempest-sw.com),

function GetCurrentProject: IOTAProject;
var
  Services          : IOTAModuleServices;
  Module            : IOTAModule;
  Project           : IOTAProject;
  ProjectGroup      : IOTAProjectGroup;
  MultipleProjects  : Boolean;
  I                 : Integer;
begin
  Result := nil;
  MultipleProjects := False;
  Services := BorlandIDEServices as IOTAModuleServices;
  for I := 0 to Services.ModuleCount - 1 do
  begin
    Module := Services.Modules[I];
    if Module.QueryInterface(IOTAProjectGroup, ProjectGroup) = S_OK then
    begin
      Result := ProjectGroup.ActiveProject;
      Exit;
    end
    else
      if Module.QueryInterface(IOTAProject, Project) = S_OK then
      begin
        if Result = nil then
          // Found the first project, so save it
          Result := Project
        else
          MultipleProjects := True;
        // It doesn't look good, but keep searching for a project group
      end;
  end;
  if MultipleProjects then
    Result := nil;
end;

function GetCurrentProjectGroup: IOTAModule;
var
  Services          : IOTAModuleServices;
  Module            : IOTAModule;
  ProjectGroup      : IOTAProjectGroup;
  I                 : Integer;
begin
  Result := nil;
  Services := BorlandIDEServices as IOTAModuleServices;
  for I := 0 to Services.ModuleCount - 1 do
  begin
    Module := Services.Modules[I];
    if Module.QueryInterface(IOTAProjectGroup, ProjectGroup) = S_OK then
    begin
      Result := Module;
      Exit;
    end
  end;
end;

function TJvFileReopener.GetName: string;
{ Return name of expert }
begin
  Result := 'ReopenFiles';
end;

function TJvFileReopener.GetState: TWizardState;
{ This expert is always enabled }
begin
  Result := [wsEnabled];
end;

function TJvFileReopener.GetIDString: string;
{ "Vendor.AppName" ID string for expert }
begin
  Result := 'jv.FileReopener';
end;

procedure TJvFileReopener.Execute;
{ Called when expert is chosen from the main menu. }
{ This procedure creates, shows, and frees the main form. }
begin
  //
end;

constructor TJvFileReopener.Create;

begin
  inherited Create;

  FMainMenu := (BorlandIDEServices as INTAServices).MainMenu;
  // find File
  FFileMenu := FMainMenu.Items.Find('File');
  Assert(FFileMenu <> nil, 'FFileMenu is nil');

  FNewMenuItem := fMainMenu.FindComponent(GetName) as TMenuItem;
  if FNewMenuItem = nil then
  begin
    FNewMenuItem := TMenuItem.Create(FFileMenu);

    FNewMenuItem.Caption := 'Reopen Files (JEDI Style) ...';
    FNewMenuItem.OnClick := OpenRecentFiles;
    FNewMenuItem.Name := GetName;

    FReopenMenuItem := FFileMenu.Find('Reopen');
    Assert(FReopenMenuItem <> nil, 'FFileMenu is nil');

    FFileMenu.Insert(fFileMenu.IndexOf(FReopenMenuItem), FNewMenuItem);
  end;

  MyIniContainer := TIniContainer.Create;
  MyIniContainer.MenuItem := FNewMenuItem;
end;

destructor TJvFileReopener.Destroy;
var
  i                 : Integer;
begin
  i := 0;
  while i < FFileMenu.Count do
  begin
    if AnsiSameCaption(FFileMenu.Items[i].Caption, GetName) then
    begin
      FFileMenu.Remove(FFileMenu.Items[i]);
    end
    else
      Inc(i);
  end;
  if FNewMenuItem <> nil then
  begin
    FNewMenuItem.Free;
  end;
  inherited Destroy;
end;

procedure TJvFileReopener.OpenRecentFiles(Sender: TObject);
var
  JvFilesListForm   : TJvFilesListForm;
  ReopenerFiles     : IReopenerFiles;
  Options           : IOptionsMemento;
begin
  MyIniContainer.SaveAll;
  ReopenerFiles := MyIniContainer;
  Options := MyIniContainer;

  JvFilesListForm := TJvFilesListForm.Create(Application, ReopenerFiles, Options);
  JvFilesListForm.Show;
end;

procedure TJvFileReopener.AfterCompile(Succeeded: Boolean);
begin
  //
end;

procedure TJvFileReopener.BeforeCompile(const Project: IOTAProject; var Cancel: Boolean);
begin
  //
end;

procedure TJvFileReopener.FileNotification(NotifyCode: TOTAFileNotification; const FileName: string; var Cancel: Boolean);
begin
  case NotifyCode of
    ofnFileOpened: MyIniContainer.LogOpenedFile(FileName);
    ofnFileClosing: MyIniContainer.LogClosingFile(FileName);
    ofnProjectDesktopSave:
      begin
        MyIniContainer.LogClosingFile(GetCurrentProject.FileName);
        MyIniContainer.LogClosingFile(GetCurrentProjectGroup.FileName);
        MyIniContainer.SaveAll;
      end;
  end;
//some time after first create the IDE clears shortcut of menu item, 
//so reassign it, but only if cleared and specified in options
  if (MyIniContainer.MenuItem.Shortcut=0) and (MyIniContainer.MenuShortcut<>0) then
    MyIniContainer.MenuItem.Shortcut := MyIniContainer.MenuShortcut;
end;

procedure TJvFileReopener.SetMyIniContainer(const Value: TIniContainer);
begin
  FMyIniContainer := Value;
end;

initialization

finalization
  (BorlandIDEServices as IOTAServices).RemoveNotifier(Index);

end.

