unit jvReopenerClasses;

interface

uses classes, SysUtils;

type

  TTimeStorage = class
  public
    fTimeOpen: string;
    fTimeClosed: string;
  end;

  TMyStringList = class(TStringList)
  published
    destructor Destroy; override;
    procedure AddTimeObject(const S: string);
    procedure UpdateTime(const i: integer; Opened, Closed: string);
    procedure Clear; override;
    procedure Delete(Index: Integer); override;

  private
    FListCapacity: Integer;

    FColumnSizes: string;
    FColumnSorting: string;
    FColumnPersistance: Boolean;
    FSortPersistance: Boolean;
    procedure SetListCapacity(const Value: Integer);
    procedure SetColumnSizes(const Value: string);

    procedure SetColumnSorting(const Value: string);
    procedure SetColumnPersistance(const Value: Boolean);
    procedure SetSortPersistance(const Value: Boolean);

  public
    procedure SortByTimeOpened;
    property ListCapacity: Integer read FListCapacity write SetListCapacity;
    property ColumnSizes: string read FColumnSizes write SetColumnSizes;

    property ColumnSorting: string read FColumnSorting write SetColumnSorting;


    property SortPersistance: Boolean read FSortPersistance write SetSortPersistance;
    property ColumnPersistance: Boolean read FColumnPersistance write SetColumnPersistance;

  end;

implementation

procedure TMyStringList.UpdateTime(const i: integer; Opened, Closed: string);
begin
  if Opened <> '' then TTimeStorage(self.Objects[i]).fTimeOpen := Opened;
  if Closed <> '' then TTimeStorage(self.Objects[i]).fTimeClosed := Closed;
end;

procedure TMyStringList.Clear;
var i               : integer;
begin
  for i := 0 to self.Count - 1 do
    self.Objects[i].Free;
  inherited;
end;

procedure TMyStringList.Delete(Index: Integer);
begin
  self.Objects[index].Free;
  inherited;
end;

destructor TMyStringList.Destroy;
begin
  self.Clear;
  inherited;
end;

procedure TMyStringList.AddTimeObject(const S: string);
begin
  self.AddObject(S, TTimeStorage.Create);
end;

procedure TMyStringList.SetListCapacity(const Value: Integer);
begin
  FListCapacity := Value;
end;

procedure TMyStringList.SetColumnSizes(const Value: string);
begin
  FColumnSizes := Value;
end;

procedure TMyStringList.SetColumnSorting(const Value: string);
begin
  FColumnSorting := Value;
end;

procedure TMyStringList.SetColumnPersistance(const Value: Boolean);
begin
  FColumnPersistance := Value;
end;

procedure TMyStringList.SetSortPersistance(const Value: Boolean);
begin
  FSortPersistance := Value;
end;

function TimeCompare(List: TStringList; Index1, Index2: Integer): Integer;
begin
Result := AnsiCompareText(TTimeStorage(List.Objects[Index1]).fTimeOpen, TTimeStorage(List.Objects[Index2]).fTimeOpen)
end;



procedure TMyStringList.SortByTimeOpened;
begin
CustomSort(TimeCompare);
end;

end.

